@@ -38,11 +38,13 @@ cc                 !
 
             real*8  ndensity         !  effective number density /cm^3
             real*8  wp    ! plasma frequency  x hbar (GeV)
-            real*8  n     ! reflactive index
+            real*8  n     ! refractive index
             real*8  nd    ! number of ingredients / cm^3 
             real*8  A     ! sum No x  Ai
             real*8  Z     ! sum No x  Zi
             real*8  Z2    ! sum No x  Zi**2
+            real*8  Z1_3rd !  <Z^1/3>  not <Z>^(1/3)
+            real*8  Z2_3rd !  <Z^2/3>  not <Z>^(2/3) 
             real*8  mbtoPgrm ! 10^-27 x N0/A. If multiplied to sigma in mb,
                            !  we obtain probability / (g/cm2).
             real*8  mbtoPcm  ! rho x mbtoPgrm. If multiplied to sigma in mb, 
