@@ -78,11 +78,11 @@ c       ********************* reset some of the cond for Cosmos
         end
 
 c      **********************************
-       subroutine ep2cosCond2(ia, iz)
+       subroutine ep2cosCond2(ia, iz, xs)
        implicit none
 #include "Zepi2cos.h"
        integer ia, iz  ! input. target nucleon number and Z
-
+       real*8 xs  !  xs in mb on this target
 #ifdef  UNIONMAP
        MovedTrack.p = aPtcl
 #else
@@ -95,15 +95,16 @@ c      **********************************
 c                 actually no track inf. needed
        TargetNucleonNo = ia
        TargetProtonNo =  iz
+       TargetXs = xs
        end
 c     ***************************
       subroutine eppushPtcl(cTrack)
 c            push Cosmos made ptlcs in the stack area
       implicit none
 #include "Zepi2cos.h"      
-#define  PTCL
+#define PTCL
 #include "ZepTrack.h"
-#undef   PTCL
+#undef PTCL
       record /epTrack/ cTrack  ! input. some track info is extracted
                               ! from here. interacting parent
 
@@ -191,11 +192,13 @@ c           constant density material
       real*8 len, minlen
 c     
       integer i
-
+c////////////////
+c      logical show
+c      common /showshow/ show
+c///////////
 c     
       minlen = Infty
 
-
       do i = 1, NumberOfInte
          if(.not. IntInfArray(i).decay) then
 c              convert kg/m2 into length in m
@@ -204,7 +207,11 @@ c            IntInfArray(i).length = IntInfArray(i).thickness*0.1/den/100.
          else
             len = IntInfArray(i).length
          endif
-
+c//////////////
+c         if(show) then
+c            write(0,*) i, len, IntInfArray(i).process 
+c         endif
+c///////////////
 
          if(i .eq. 1 .or.  len .lt. minlen) then
                ProcessNo = i
@@ -220,6 +227,11 @@ c     *     IntInfArray(ProcessNo).length*100. * den*10. ! cm g/cm3*10-> kg/m2
       endif
       gramcm2 = IntInfArray(ProcessNo).thickness * 0.1   ! in g/cm2
       proc = IntInfArray(ProcessNo).process
+c/////////////
+c      if(show) then
+c         write(0,*) ' proc selected=',proc
+c      endif
+c//////////
       end
 c     *********************************************
       subroutine epsampPtcl(aPtcl)
@@ -253,78 +265,69 @@ c     **************************************************
 c
       record /epmedia/ media  ! input.
 
-      real*8 mfp, ek,  xs, et, mass
+      real*8 mfp,  xs, mass
 
 
 c        m.f.p (kg/m**2) = abn /xsec(mb)
 c        parameter (aira=14.5, abogn=6.02e23, abn=aira*1.e28/abogn)
-      real*8 abogn, toabn
-      parameter (abogn=6.02d23, toabn=1.d28/abogn)
+c      real*8 abogn, toabn
+c      parameter (abogn=6.02d23, toabn=1.d28/abogn)
       real*8 collkgram, u, length
-      real*8  eps/1.e-8/, smallxs/1.e-10/, largexs/1.e10/
-      integer subcode, icon
 
-      et = TrackBefMove.p.fm.p(4)
-      mass = TrackBefMove.p.mass
-      ek = max(et - mass, eps)    ! avoid 0 energy.
+
 
 
       call cdecayLeng(TrackBefMove, length)
 
+
       if(length .ne. Infty) then
          call csetIntInf(length, .true., 'decay')
       endif
 
       if( TrackBefMove.p.code .eq. kmuon) return   ! ****************
 
-      call epgetxs(ActiveMdl, TrackBefMove.p, media, xs, mfp,  icon)
-      if(icon .eq. 0) then
+      call epgetxs(ActiveMdl, TrackBefMove.p, media, xs, mfp)
+      if(xs == smallxs ) then
+         collkgram = Infty
+      elseif(xs == largexs) then
+         collkgram = 0.
+      else
          call rndc(u)
          collkgram = -mfp*log(u)
-      elseif(icon .eq. -1) then
-         collkgram = Infty
-      elseif(icon .eq. 1) then
-         collkgram = 0.
-      elseif(icon .eq. 2) then
-c           heavy xs.  this case we directory obtain the
-c        AA' cross-section. In case of gheisha and
-c             A<=4, it has been treated already.
-c
-         write(0,*) ' we should not come here'
-         write(0,*) ' proj. cod, Ee=',TrackBefMove.p.code,
-     *    TrackBefMove.p.fm.p(4), ' media=',media.name
-         stop
       endif
-c  &&&&&&  confirmed o.k
-c      write(*,*) ' media=',media.name, ' ek=',ek,' mfp=', mfp
-c  &&&&
+
       call csetIntInf(collkgram, .false., 'coll')            
       end
+
       subroutine epsaveFirstCol
 c        This is called only when the first nuclear interaction
 c        or decay to save the collision info.
       implicit none
-#include "ZepMaxdef.h"
 #include "Zepi2cos.h"      
-#define  PTCL
-#include "ZepTrack.h"
-#undef   PTCL
+#include "ZepMaxdef.h"
+
 
       record /ptcl/ ptclSave(EPMAX_STACK)
       integer nptcls
       common /stackSavec/ ptclSave, nptcls
       
       integer i
+      if( Nproduced >  EPMAX_STACK) then
+         write(0,*) "warning, first interacton generated "
+         write(0,*) "particls > ", EPMAX_STACK
+         write(0,*) " only first ", EPMAX_STACK, " is sotred"
+         write(0,*) " for the first interaction  info"
+      endif
+      nptcls = min(Nproduced, EPMAX_STACK)
 
-      do i = 1,  Nproduced
+      do i = 1,  nptcls
          ptclSave(i) = Pwork(i)
       enddo
-      nptcls = Nproduced
       end
       subroutine epqFirstColPtcls(ptcls, n, m)
         implicit none
-#include  "ZepTrack.h"
-#include  "ZepStack.h"
+#include  "Zptcl.h"
+#include "ZepMaxdef.h"
       record /ptcl/ ptclSave(EPMAX_STACK)
       integer nptcls
       common /stackSavec/ ptclSave, nptcls
