@@ -227,6 +227,7 @@ c  #include "ZepTrackp.h"
          else
             call cinelx(pj, tga, xs)
          endif
+
          if( xs == smallxs .or. xs == largexs ) then
             sumns = xs
             exit
@@ -386,3 +387,27 @@ c          int value is taken.
       media.colA = ia
       media.colXs = media.nsigma(j)/media.npercm3(j)
       end
+
+
+      subroutine epgetCaprate( media)
+      implicit none
+#include "Zptcl.h"
+#include "Zcode.h"
+#include "Zmedia.h"
+#include "Zevhnp.h"
+          
+      record /epmedia/ media  ! input
+ 
+      integer i
+      real(8):: sumns, capr
+
+      sumns = 0.
+      do i = 1, media.noOfElem
+         call cmucap( int(media.elem(i).A), int(media.elem(i).Z), 
+     *            capr)
+         media.nsigma(i) = capr*media.npercm3(i)
+         sumns = sumns + media.nsigma(i)
+      enddo
+      media.sumns = sumns
+      end
+
